@@ -15,19 +15,17 @@
 G_BEGIN_DECLS
 
 GPtrArray *
-xb_silo_query_sn_with_root(XbSilo *self,
-			   XbNode *n,
-			   const gchar *xpath,
-			   guint limit,
-			   GError **error);
+xb_silo_query_sn_with_root(XbSilo *self, XbNode *n, const gchar *xpath, guint limit, GError **error)
+    G_GNUC_NON_NULL(1, 3);
 GPtrArray *
-xb_silo_query_with_root(XbSilo *self, XbNode *n, const gchar *xpath, guint limit, GError **error);
+xb_silo_query_with_root(XbSilo *self, XbNode *n, const gchar *xpath, guint limit, GError **error)
+    G_GNUC_NON_NULL(1, 3);
 GPtrArray *
 xb_silo_query_with_root_full(XbSilo *self,
 			     XbNode *n,
 			     XbQuery *query,
 			     XbQueryContext *context,
 			     gboolean first_result_only,
-			     GError **error);
+			     GError **error) G_GNUC_NON_NULL(1, 3);
 
 G_END_DECLS
