@@ -215,7 +215,7 @@ xb_silo_strtab_index_lookup(XbSilo *self, const gchar *str)
 }
 
 /* private */
-inline XbSiloNode *
+XbSiloNode *
 xb_silo_get_node(XbSilo *self, guint32 off)
 {
 	XbSiloPrivate *priv = GET_PRIVATE(self);
@@ -811,7 +811,9 @@ xb_silo_set_profile_flags(XbSilo *self, XbSiloProfileFlags profile_flags)
 
 	/* proxy */
 	if (profile_flags & XB_SILO_PROFILE_FLAG_OPTIMIZER) {
-		xb_machine_set_debug_flags(priv->machine, XB_MACHINE_DEBUG_FLAG_SHOW_OPTIMIZER);
+		xb_machine_set_debug_flags(priv->machine,
+					   XB_MACHINE_DEBUG_FLAG_SHOW_OPTIMIZER |
+					       XB_MACHINE_DEBUG_FLAG_SHOW_SLOW_PATH);
 	}
 }
 
@@ -1187,8 +1189,8 @@ xb_silo_machine_fixup_position_cb(XbMachine *self,
 
 	/* always exists, but maybe a @level would be cleaner */
 	if (tail != NULL) {
-		xb_opcode_set_level(op1, xb_opcode_get_level(tail));
-		xb_opcode_set_level(op2, xb_opcode_get_level(tail));
+		xb_opcode_set_level(op1, _xb_opcode_get_level(tail));
+		xb_opcode_set_level(op2, _xb_opcode_get_level(tail));
 	}
 
 	return TRUE;
@@ -1213,8 +1215,8 @@ xb_silo_machine_fixup_attr_exists_cb(XbMachine *self,
 
 	/* always exists, but maybe a @level would be cleaner */
 	if (tail != NULL) {
-		xb_opcode_set_level(op1, xb_opcode_get_level(tail));
-		xb_opcode_set_level(op2, xb_opcode_get_level(tail));
+		xb_opcode_set_level(op1, _xb_opcode_get_level(tail));
+		xb_opcode_set_level(op2, _xb_opcode_get_level(tail));
 	}
 
 	return TRUE;
@@ -1515,6 +1517,16 @@ xb_silo_machine_func_search_cb(XbMachine *self,
 	if (!xb_machine_stack_pop_two(self, stack, &op1, &op2, error))
 		return FALSE;
 
+	/* this cannot be optimized away when constructing the query */
+	if (!_xb_opcode_has_flag(&op1, XB_OPCODE_FLAG_TOKENIZED) &&
+	    _xb_opcode_get_kind(&op1) == XB_OPCODE_KIND_BOUND_TEXT) {
+		xb_machine_opcode_tokenize(self, &op1);
+	}
+	if (!_xb_opcode_has_flag(&op2, XB_OPCODE_FLAG_TOKENIZED) &&
+	    _xb_opcode_get_kind(&op2) == XB_OPCODE_KIND_BOUND_TEXT) {
+		xb_machine_opcode_tokenize(self, &op2);
+	}
+
 	/* TOKN:TOKN */
 	if (xb_opcode_has_flag(&op1, XB_OPCODE_FLAG_TOKENIZED) &&
 	    xb_opcode_has_flag(&op2, XB_OPCODE_FLAG_TOKENIZED)) {
@@ -1829,7 +1841,6 @@ xb_silo_lookup_query(XbSilo *self, const gchar *xpath)
 
 	if (result != NULL) {
 		g_object_ref(result);
-		g_debug("Found cached query ‘%s’ (%p) in silo %p", xpath, result, self);
 	} else {
 		g_autoptr(XbQuery) query = NULL;
 
@@ -1838,7 +1849,6 @@ xb_silo_lookup_query(XbSilo *self, const gchar *xpath)
 		result = g_hash_table_lookup(priv->query_cache, xpath);
 		if (result != NULL) {
 			g_object_ref(result);
-			g_debug("Found cached query ‘%s’ (%p) in silo %p", xpath, result, self);
 		} else {
 			g_autoptr(GError) error_local = NULL;
 
