@@ -11,6 +11,7 @@
 #include "xb-silo.h"
 
 gchar *
-xb_value_bindings_to_string(XbValueBindings *self);
+xb_value_bindings_to_string(XbValueBindings *self) G_GNUC_NON_NULL(1);
 gboolean
-xb_value_bindings_indexed_text_lookup(XbValueBindings *self, XbSilo *silo, GError **error);
+xb_value_bindings_indexed_text_lookup(XbValueBindings *self, XbSilo *silo, GError **error)
+    G_GNUC_NON_NULL(1, 2);
